[SCM] Samba Shared Repository - branch master updated

Andreas Schneider asn at samba.org
Wed May 5 07:37:15 MDT 2010


The branch, master has been updated
       via  b4c46bd... libwbclient: Fixed doxygen errors.
      from  6214354... Fixed issue with return in a void function found by Björn JACKE <bj at SerNet.DE>

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit b4c46bd7dfd268cf6f9390374a7638a548308064
Author: Andreas Schneider <asn at samba.org>
Date:   Wed May 5 15:33:09 2010 +0200

    libwbclient: Fixed doxygen errors.

-----------------------------------------------------------------------

Summary of changes:
 nsswitch/libwbclient/wbc_sid_async.c |   28 +++++++++++++++++-----------
 nsswitch/libwbclient/wbclient.c      |   22 +++++++++++-----------
 nsswitch/libwbclient/wbclient.h      |    7 ++++---
 3 files changed, 32 insertions(+), 25 deletions(-)


Changeset truncated at 500 lines:

diff --git a/nsswitch/libwbclient/wbc_sid_async.c b/nsswitch/libwbclient/wbc_sid_async.c
index b94b88d..828e3b4 100644
--- a/nsswitch/libwbclient/wbc_sid_async.c
+++ b/nsswitch/libwbclient/wbc_sid_async.c
@@ -36,7 +36,7 @@ struct wbc_lookup_name_state {
 static void wbcLookupName_done(struct tevent_req *subreq);
 
 /**
- * @brief Request a conversion of a domaind and name to a domain sid
+ * @brief Request a conversion of a domain and name to a domain sid
  *
  * @param mem_ctx	talloc context to allocate the request from
  * @param ev		tevent context to use for async operation
@@ -118,15 +118,16 @@ static void wbcLookupName_done(struct tevent_req *subreq)
 }
 
 /**
- * @brief Receive a conversion a SID to a domain and name
+ * @brief Receive a conversion of a domain and name to a domain SID.
+ *
+ * @param req The tevent request calling this function.
+ *
+ * @param sid A pointer to store the sid looked up.
  *
- * @param *
- * @param *pname	Resolved User or group name
- * @param *pname_type	Pointer to the resolved SID type
+ * @param name_type Pointer to store the resolved SID name type.
  *
  * @return #wbcErr
  */
-
 wbcErr wbcLookupName_recv(struct tevent_req *req,
 			  struct wbcDomainSid *sid,
 			  enum wbcSidType *name_type)
@@ -245,14 +246,19 @@ static void wbcLookupSid_done(struct tevent_req *subreq)
 /**
  * @brief Receive a conversion a SID to a domain and name
  *
- * @param *mem_ctx,	talloc context to move results to
- * @param *pdomain	Resolved Domain name (possibly "")
- * @param *pname	Resolved User or group name
- * @param *pname_type	Pointer to the resolved SID type
+ * @param req          The tevent request calling this function.
+ *
+ * @param mem_ctx      A talloc context to move results to.
+ *
+ * @param pdomain      A pointer to store the resolved domain name
+ *                      (possibly "").
+ *
+ * @param pname        A pointer to store the resolved user or group name.
+ *
+ * @param pname_type   A pointer to store the resolved SID type.
  *
  * @return #wbcErr
  */
-
 wbcErr wbcLookupSid_recv(struct tevent_req *req,
 			 TALLOC_CTX *mem_ctx,
 			 char **pdomain,
diff --git a/nsswitch/libwbclient/wbclient.c b/nsswitch/libwbclient/wbclient.c
index 2792827..15be255 100644
--- a/nsswitch/libwbclient/wbclient.c
+++ b/nsswitch/libwbclient/wbclient.c
@@ -34,16 +34,7 @@ NSS_STATUS winbindd_priv_request_response(int req_type,
 					  struct winbindd_request *request,
 					  struct winbindd_response *response);
 
-/** @brief Wrapper around Winbind's send/receive API call
- *
- * @param cmd       Winbind command operation to perform
- * @param request   Send structure
- * @param response  Receive structure
- *
- * @return #wbcErr
- **/
-
-/**********************************************************************
+/*
  result == NSS_STATUS_UNAVAIL: winbind not around
  result == NSS_STATUS_NOTFOUND: winbind around, but domain missing
 
@@ -54,7 +45,7 @@ NSS_STATUS winbindd_priv_request_response(int req_type,
  (as far as I have seen) with the callers of is_trusted_domains.
 
  --Volker
-**********************************************************************/
+*/
 
 static wbcErr wbcRequestResponseInt(
 	int cmd,
@@ -89,6 +80,15 @@ static wbcErr wbcRequestResponseInt(
 	return wbc_status;
 }
 
+/**
+ * @brief Wrapper around Winbind's send/receive API call
+ *
+ * @param cmd       Winbind command operation to perform
+ * @param request   Send structure
+ * @param response  Receive structure
+ *
+ * @return #wbcErr
+ */
 wbcErr wbcRequestResponse(int cmd,
 			  struct winbindd_request *request,
 			  struct winbindd_response *response)
diff --git a/nsswitch/libwbclient/wbclient.h b/nsswitch/libwbclient/wbclient.h
index 718c9f6..e2f9890 100644
--- a/nsswitch/libwbclient/wbclient.h
+++ b/nsswitch/libwbclient/wbclient.h
@@ -982,13 +982,14 @@ wbcErr wbcGetGroups(const char *account,
 /**
  * @brief Lookup the current status of a trusted domain
  *
  * @param domain      Domain to query
  * @param *info       Pointer to returned domain_info struct
  *
  * @return #wbcErr
  **/
 wbcErr wbcDomainInfo(const char *domain,
-		     struct wbcDomainInfo **info);
+		     struct wbcDomainInfo **dinfo);
 
 /**
  * @brief Enumerate the domain trusts known by Winbind
@@ -982,13 +982,14 @@ wbcErr wbcGetGroups(const char *account,
  * @brief Lookup the current status of a trusted domain
  *
- * @param domain      Domain to query
- * @param *info       Pointer to returned domain_info struct
+ * @param domain        The domain to query
+ *
+ * @param dinfo          A pointer to store the returned domain_info struct.
  *
  * @return #wbcErr


-- 
Samba Shared Repository


More information about the samba-cvs mailing list